# Generated by roxygen2: do not edit by hand

S3method(plot,gof_battery)
S3method(print,gof_battery)
export(cdef.gof)
export(def.ensemble.gof)
export(def.gof)
export(deploy.gof)
export(edge.gof)
export(edges.gof)
export(ef.gof)
export(gof.features)
export(gof_install_suggests)
export(run.all.gof)
importFrom(graphics,plot)
importFrom(stats,anova)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,deviance)
importFrom(stats,dist)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,glm.fit)
importFrom(stats,kmeans)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,poly)
importFrom(stats,predict)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,capture.output)
